pub struct OrderByInt<T>(pub T)
where
T: IntegerId;Expand description
Tuple Fields
0: TTrait Implementations
Sourceimpl<T> AsMut<T> for OrderByInt<T>where
T: IntegerId,
impl<T> AsMut<T> for OrderByInt<T>where
T: IntegerId,
Sourceimpl<T> AsRef<T> for OrderByInt<T>where
T: IntegerId,
impl<T> AsRef<T> for OrderByInt<T>where
T: IntegerId,
Sourceimpl<T> Clone for OrderByInt<T>
impl<T> Clone for OrderByInt<T>
Sourcefn clone(&self) -> OrderByInt<T>
fn clone(&self) -> OrderByInt<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<T> Copy for OrderByInt<T>
Sourceimpl<T> Debug for OrderByInt<T>
impl<T> Debug for OrderByInt<T>
Sourceimpl<T> Default for OrderByInt<T>
impl<T> Default for OrderByInt<T>
Sourcefn default() -> OrderByInt<T>
fn default() -> OrderByInt<T>
Returns the “default value” for a type. Read more
impl<T> Eq for OrderByInt<T>where
T: IntegerId,
Sourceimpl<T> EquivalentId<T> for OrderByInt<T>where
T: IntegerId,
impl<T> EquivalentId<T> for OrderByInt<T>where
T: IntegerId,
Sourceimpl<T> EquivalentId<T> for &OrderByInt<T>where
T: IntegerId,
impl<T> EquivalentId<T> for &OrderByInt<T>where
T: IntegerId,
Sourceimpl<T> From<T> for OrderByInt<T>where
T: IntegerId,
impl<T> From<T> for OrderByInt<T>where
T: IntegerId,
Sourcefn from(value: T) -> OrderByInt<T>
fn from(value: T) -> OrderByInt<T>
Converts to this type from the input type.
Sourceimpl<T> Hash for OrderByInt<T>where
T: IntegerId,
impl<T> Hash for OrderByInt<T>where
T: IntegerId,
Sourceimpl<T> IntegerId for OrderByInt<T>where
T: IntegerId,
impl<T> IntegerId for OrderByInt<T>where
T: IntegerId,
Sourceconst MIN_ID: Option<OrderByInt<T>>
const MIN_ID: Option<OrderByInt<T>>
The value of this type with the smallest integer value,
or
None if this type is uninhabited.Sourceconst MAX_ID: Option<OrderByInt<T>>
const MAX_ID: Option<OrderByInt<T>>
The value of this type with the largest integer value,
or
None if this type is uninhabited.Sourceconst MIN_ID_INT: Option<<OrderByInt<T> as IntegerId>::Int> = <T as crate::IntegerId>::MIN_ID_INT
const MIN_ID_INT: Option<<OrderByInt<T> as IntegerId>::Int> = <T as crate::IntegerId>::MIN_ID_INT
Sourceconst MAX_ID_INT: Option<<OrderByInt<T> as IntegerId>::Int> = <T as crate::IntegerId>::MAX_ID_INT
const MAX_ID_INT: Option<<OrderByInt<T> as IntegerId>::Int> = <T as crate::IntegerId>::MAX_ID_INT
Sourceconst TRUSTED_RANGE: Option<TrustedRangeToken<OrderByInt<T>>>
const TRUSTED_RANGE: Option<TrustedRangeToken<OrderByInt<T>>>
Indicates that the type’s implementation of
IntegerId::to_int can be trusted
to only return values in the range MIN_ID_INT..=MAX_ID_INT. Read moreSourcefn from_int(id: <OrderByInt<T> as IntegerId>::Int) -> OrderByInt<T>
fn from_int(id: <OrderByInt<T> as IntegerId>::Int) -> OrderByInt<T>
Create an id from the underlying integer value,
panicking if the value is invalid. Read more
Sourcefn from_int_checked(
id: <OrderByInt<T> as IntegerId>::Int,
) -> Option<OrderByInt<T>>
fn from_int_checked( id: <OrderByInt<T> as IntegerId>::Int, ) -> Option<OrderByInt<T>>
Create an id from the underlying integer value,
returning
None if the value is invalid.Sourceunsafe fn from_int_unchecked(
id: <OrderByInt<T> as IntegerId>::Int,
) -> OrderByInt<T>
unsafe fn from_int_unchecked( id: <OrderByInt<T> as IntegerId>::Int, ) -> OrderByInt<T>
Create an id from the underlying integer value,
triggering undefined behavior if the value is invalid. Read more
impl<T> IntegerIdContiguous for OrderByInt<T>where
T: IntegerIdContiguous,
Sourceimpl<T> IntegerIdCounter for OrderByInt<T>where
T: IntegerIdCounter,
impl<T> IntegerIdCounter for OrderByInt<T>where
T: IntegerIdCounter,
Sourceconst START: OrderByInt<T>
const START: OrderByInt<T>
Where a counter a should start from. Read more
Sourceimpl<T> Ord for OrderByInt<T>where
T: IntegerId,
impl<T> Ord for OrderByInt<T>where
T: IntegerId,
Sourcefn cmp(&self, other: &OrderByInt<T>) -> Ordering
fn cmp(&self, other: &OrderByInt<T>) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl<T> PartialEq for OrderByInt<T>where
T: IntegerId,
impl<T> PartialEq for OrderByInt<T>where
T: IntegerId,
Sourceimpl<T> PartialEq<T> for OrderByInt<T>where
T: IntegerId,
impl<T> PartialEq<T> for OrderByInt<T>where
T: IntegerId,
Sourceimpl<T> PartialOrd for OrderByInt<T>where
T: IntegerId,
impl<T> PartialOrd for OrderByInt<T>where
T: IntegerId,
Sourceimpl<T> PartialOrd<T> for OrderByInt<T>where
T: IntegerId,
impl<T> PartialOrd<T> for OrderByInt<T>where
T: IntegerId,